@@ -30,13 +30,12 @@ import (
 
 	"github.com/compose-spec/compose-go/v2/paths"
 	"github.com/compose-spec/compose-go/v2/types"
-	cerrdefs "github.com/containerd/errdefs"
+	"github.com/containerd/errdefs"
 	"github.com/docker/docker/api/types/blkiodev"
 	"github.com/docker/docker/api/types/container"
 	"github.com/docker/docker/api/types/filters"
 	"github.com/docker/docker/api/types/mount"
 	"github.com/docker/docker/api/types/network"
-	"github.com/docker/docker/api/types/strslice"
 	"github.com/docker/docker/api/types/versions"
 	volumetypes "github.com/docker/docker/api/types/volume"
 	"github.com/docker/go-connections/nat"
@@ -181,15 +180,12 @@ func (s *composeService) getCreateConfigs(ctx context.Context,
 		return createConfigs{}, err
 	}
 
-	var (
-		runCmd     strslice.StrSlice
-		entrypoint strslice.StrSlice
-	)
+	var runCmd, entrypoint []string
 	if service.Command != nil {
-		runCmd = strslice.StrSlice(service.Command)
+		runCmd = service.Command
 	}
 	if service.Entrypoint != nil {
-		entrypoint = strslice.StrSlice(service.Entrypoint)
+		entrypoint = service.Entrypoint
 	}
 
 	var (
@@ -286,8 +282,8 @@ func (s *composeService) getCreateConfigs(ctx context.Context,
 		Annotations:    service.Annotations,
 		Binds:          binds,
 		Mounts:         mounts,
-		CapAdd:         strslice.StrSlice(service.CapAdd),
-		CapDrop:        strslice.StrSlice(service.CapDrop),
+		CapAdd:         service.CapAdd,
+		CapDrop:        service.CapDrop,
 		NetworkMode:    networkMode,
 		Init:           service.Init,
 		IpcMode:        container.IpcMode(service.Ipc),
@@ -1266,7 +1262,7 @@ func (s *composeService) ensureNetwork(ctx context.Context, project *types.Proje
 	}
 
 	id, err := s.resolveOrCreateNetwork(ctx, project, name, n)
-	if cerrdefs.IsConflict(err) {
+	if errdefs.IsConflict(err) {
 		// Maybe another execution of `docker compose up|run` created same network
 		// let's retry once
 		return s.resolveOrCreateNetwork(ctx, project, name, n)
@@ -1432,7 +1428,7 @@ func (s *composeService) removeDivergedNetwork(ctx context.Context, project *typ
 	err := s.stop(ctx, project.Name, api.StopOptions{
 		Services: services,
 		Project:  project,
-	})
+	}, nil)
 	if err != nil {
 		return nil, err
 	}
@@ -1501,7 +1497,7 @@ func (s *composeService) resolveExternalNetwork(ctx context.Context, n *types.Ne
 		sn, err := s.apiClient().NetworkInspect(ctx, n.Name, network.InspectOptions{})
 		if err == nil {
 			networks = append(networks, sn)
-		} else if !cerrdefs.IsNotFound(err) {
+		} else if !errdefs.IsNotFound(err) {
 			return "", err
 		}
 
@@ -1538,7 +1534,7 @@ func (s *composeService) resolveExternalNetwork(ctx context.Context, n *types.Ne
 func (s *composeService) ensureVolume(ctx context.Context, name string, volume types.VolumeConfig, project *types.Project, assumeYes bool) (string, error) {
 	inspected, err := s.apiClient().VolumeInspect(ctx, volume.Name)
 	if err != nil {
-		if !cerrdefs.IsNotFound(err) {
+		if !errdefs.IsNotFound(err) {
 			return "", err
 		}
 		if volume.External {
@@ -1603,7 +1599,7 @@ func (s *composeService) removeDivergedVolume(ctx context.Context, name string,
 	err := s.stop(ctx, project.Name, api.StopOptions{
 		Services: services,
 		Project:  project,
-	})
+	}, nil)
 	if err != nil {
 		return err
 	}
@@ -1627,7 +1623,7 @@ func (s *composeService) removeDivergedVolume(ctx context.Context, name string,
 }
 
 func (s *composeService) createVolume(ctx context.Context, volume types.VolumeConfig) error {
-	eventName := fmt.Sprintf("Volume %q", volume.Name)
+	eventName := fmt.Sprintf("Volume %s", volume.Name)
 	w := progress.ContextWriter(ctx)
 	w.Event(progress.CreatingEvent(eventName))
 	hash, err := VolumeHash(volume)
